@@ -14,16 +14,37 @@
 """Produces a ShortestPaths demo."""
 
 import click
+import networkx as nx
 
 from shortestpaths import (core,  # noqa F401
                            graph_generator,
+                           io,
                            post_processing,
                            utils)
 
 
 @click.group(invoke_without_command=True)
 @click.pass_context
-@click.argument("n", type=click.INT)
+@click.option("--path", type=click.STRING, default=None, show_default=True,
+              help=("The NetworkX-file path to read the graph from. If not"
+                    " provided, a random graph of n nodes will be generated.\n"
+                    "Supported formats:\n"
+                    "[.adjlist, .edgelist, .gexf, .gml, .gpickle]\n"
+                    "Note that .adjlist does not include weights."))
+@click.option("--nodetype", default="int", show_default=True,
+              help="convert nodes to this type")
+@click.option("--comments", type=click.STRING, default='#', show_default=True,
+              help="marker for comment lines")
+@click.option("--delimiter", type=click.STRING, default=' ', show_default=True,
+              help="Separator for node labels. The default is whitespace.")
+@click.option("--encoding", type=click.STRING,
+              default="utf-8", show_default=True)
+@click.option('-s', "--source", default=None, show_default=True,
+              help="If a graph is not provided, the source defaults to node 1")
+@click.option('-t', "--target", default=None, show_default=True,
+              help="If a graph is not provided, the target defaults to node n")
+@click.option('-n', type=click.INT, default=100, show_default=True,
+              help="number of nodes (used when path is None)")
 @click.option("--weighted/--no-weighted", default=True, show_default=True)
 @click.option("--directed", is_flag=True)
 @click.option("--weights-on", default="edges-and-nodes", show_default=True,
@@ -41,16 +62,23 @@ from shortestpaths import (core,  # noqa F401
               help="whether to use multiprocessing or not")
 @click.option('-d', "--dynamic", is_flag=True,
               help="whether to use dynamic programming or not")
-@click.option('-s', "--seed", "random_seed", type=click.INT,
+@click.option("--seed", "random_seed", type=click.INT,
               default=None, show_default=True,
               help="If provided, a fixed random graph will be generated.")
 @click.option("--layout-seed", type=click.INT, default=1, show_default=True,
-              help="Fixes the random initialization of the spirng_layout.")
+              help="Fixes the random initialization of the spring_layout.")
 @click.option("--show-graph", is_flag=True, help="plots up to 8 paths")
 @click.option("--save-graph", is_flag=True, help="format: png")
 @click.option('-v', "--verbose", count=True)
 # @utils.time_this
 def main(ctx,
+         path,
+         nodetype,
+         comments,
+         delimiter,
+         encoding,
+         source,
+         target,
          n,
          weighted,
          directed,
@@ -70,13 +98,40 @@ def main(ctx,
          verbose):
 
   # 1. Preprocessing
-  adj_list, G = graph_generator.random_graph(n=n,
-                                             weighted=weighted,
-                                             directed=directed,
-                                             weights_on=weights_on,
-                                             max_edge_weight=max_edge_weight,
-                                             max_node_weight=max_node_weight,
-                                             random_seed=random_seed)
+  if path is None:
+    decoder = None
+    source = int(source) if source else 1
+    target = int(target) if target else n
+    adj_list, G = graph_generator.random_graph(
+        n=n,
+        weighted=weighted,
+        directed=directed,
+        weights_on=weights_on,
+        max_edge_weight=max_edge_weight,
+        max_node_weight=max_node_weight,
+        random_seed=random_seed
+    )
+  else:
+    if (source is None) or (target is None):
+      raise Exception("Both source and target sould be defined via the -s and"
+                      " -t options.")
+    nodetype = utils.str_to_type(nodetype)
+    read_graph_config = {
+        "path": path,
+        "nodetype": nodetype,
+        "comments": comments,
+        "delimiter": delimiter,
+        "encoding": encoding
+    }
+    if directed:
+      read_graph_config["create_using"] = nx.DiGraph
+    else:
+      read_graph_config["create_using"] = nx.Graph
+
+    adj_list, G, encoder, decoder = io.read_graph(read_graph_config, weighted)
+    source = encoder[nodetype(source)]
+    target = encoder[nodetype(target)]
+
   if dynamic:
     bidirectional = True
   if bidirectional:
@@ -87,8 +142,8 @@ def main(ctx,
   init_config = {
       "adj_list": adj_list,
       "adj_list_reverse": adj_list_reverse,
-      "source": 1,
-      "sink": n
+      "source": source,
+      "sink": target
   }
   mode = {
       "bidirectional": bidirectional,
@@ -105,6 +160,7 @@ def main(ctx,
       "layout_seed": layout_seed,
       "show_graph": show_graph,
       "save_graph": save_graph,
+      "decoder": decoder
   }
   if ctx.invoked_subcommand is not None:
     if ctx.invoked_subcommand == "dynamic_graph_demo":
@@ -118,11 +174,15 @@ def main(ctx,
   # 2. Paths generation
   k_paths = core.k_shortest_paths(K, mode, init_config)
 
+  if decoder:
+    k_paths = graph_generator.decode_path_nodes(k_paths, decoder)
+
   # 3. Post-processing
   if verbose:
     post_processing.print_paths(k_paths)
   if save_graph or show_graph:
     ctx_config.pop("init_config")
+    ctx_config.pop("decoder")
     post_processing.plot_paths(paths_data=k_paths, **ctx_config)
 
 
@@ -156,6 +216,10 @@ def replacement_paths(ctx, failing, online):
   ctx.obj["mode"].update({"failing": failing, "online": online})
   r_paths = core.replacement_paths(ctx.obj["mode"], ctx.obj.pop("init_config"))
 
+  decoder = ctx.obj.pop("decoder", None)
+  if decoder:
+    r_paths = graph_generator.decode_path_nodes(r_paths, decoder)
+
   if ctx.obj["mode"]["verbose"]:
     post_processing.print_paths(r_paths, ctx.obj["mode"]["failing"])
   if ctx.obj["save_graph"] or ctx.obj["show_graph"]:
